netapp_ontap.models.storage_unit_movement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_movement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitMovementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitMovement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `destination: StorageUnitMovementDestination GET`

    The destination of a storage unit move operation.

  `percent_complete: Size GET`

    The percentage complete of the storage unit move operation.
    There is an added computational cost to retrieving this property's value. It is not populated for a GET request unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

  `source: StorageUnitMovementSource GET`

    The source of a storage unit move operation.

  `start_time: ImpreciseDateTime GET`

    The start date and time of the storage unit move operation.
    There is an added computational cost to retrieving this property's value. It is not populated for a GET request unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

    Example: 2024-12-07T08:45:12.000+0000

  `state: str GET PATCH`

    The state of the storage unit move operation.
    The state can be updated to influence the progress of an on-going storage unit move operation. The allowed new state depends on the current state: - Update the state to `aborted` to cancel the storage unit move operation. - Update the state to `cutover` to trigger cutover of the storage unit move operation. - Update the state to `paused` to pause an in progress storage unit move operation. If the move operation has just begun replication, an update to `paused` may not be immediately possible, in which case it will fail with error 5376518 and require a retry. - Update the state to `replicating` to resume a paused storage unit move operation. - Update the state to `cutover_wait` to go into cutover for the storage unit move operation, manually. When the storage unit move operation is waiting to go into the `cutover` state, the state is `cutover_pending`.
    There is an added computational cost to retrieving this property's value. It is not populated for a GET request unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

    Valid choices:

    - aborted
    - cutover
    - cutover_wait
    - cutover_pending
    - failed
    - paused
    - queued
    - replicating
    - success